@@ -73,6 +73,9 @@ class __abr2keyDict(dict):
     proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
 
     def __polulate(self):
+        #JOAO
+        global prpNames, prpKeys, prop2key
+        #JOAO
         r = requests.get(self.proplistUrl)
         prpDict = r.json()
         prpNames = []
@@ -82,6 +85,11 @@ class __abr2keyDict(dict):
             prpNames += pcls['name']
             prpKeys += pcls['key']
         prop2key = dict(zip(prpNames, prpKeys))
+        #JOAO
+        print ("prpNames = ", prpNames)
+        print("prpKeys = ", prpKeys)
+        print("prop2key: ", prop2key)
+        #JOAO
         for prpName, prpKey in prop2key.items():
             self.__dict__[prop2abr[prpName]] = prpKey
 
